"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var sbm_http_client_service_1 = require("../../services/sbm-http-client.service");
var http_1 = require("@angular/common/http");
var devextreme_angular_1 = require("devextreme-angular");
var funcoes_component_1 = require("../../models/funcoes.component");
var material_1 = require("@angular/material");
var dialog_audit_component_1 = require("../crud/dialog-audit/dialog-audit.component");
var AuditComponent = /** @class */ (function () {
    function AuditComponent(_http, dialog) {
        this._http = _http;
        this.dialog = dialog;
        this.buttonExport = false;
        this.entity = "";
        this._columns = "col l12 s12 m12 z-depth-1";
        this.parametersVisible = true;
        this._showHideParameters = false;
        this.showParameters = {
            icon: "keyboard_arrow_left"
        };
        this.operationDescriptions = {
            between: "Entre",
            contains: "Contém",
            endsWiht: "Terminar Com",
            equals: "Igual",
            greaterThan: "Maior que",
            greaterThanOrEqual: "Maior ou igual a",
            lessThan: "Menor que",
            lessThanOrEqual: "Menor ou igual a",
            notContains: "Não contém",
            notEqual: "Diferente",
            startWith: "começar com"
        };
        this.operations = [
            {
                text: "Inclusão",
                value: "INCLUSAO"
            },
            {
                text: "Remoção",
                value: "REMOCAO"
            },
            {
                text: "Atualização",
                value: "ATUALIZACAO"
            }
        ];
        this.disabledField = true;
        this.disabledTable = true;
        this.loadingReq = false;
        this.filtroTabela = [];
        this.filtroAtributos = [];
        this.setGrid = [];
        this.selectedRow = [];
        this.colunas = [];
    }
    Object.defineProperty(AuditComponent.prototype, "columns", {
        get: function () {
            return this._columns;
        },
        set: function (value) {
            this._columns = "col l" + value + " s12 m12 z-depth-1";
        },
        enumerable: true,
        configurable: true
    });
    AuditComponent.prototype.showHideParameters = function () {
        this.parametersVisible = !this.parametersVisible;
    };
    AuditComponent.prototype.clickApp = function (event) {
        var _this = this;
        this.loadingReq = true;
        this._http.get("/sabium/api/aplicacao/" + event.id).subscribe(function (ret) {
            if (ret) {
                if (ret.entidades.length > 0) {
                    _this.filtroTabela = ret.entidades;
                    _this.loadingReq = false;
                }
                _this.disabledTable = false;
            }
        }, function (err) {
            console.log("erro");
        });
    };
    AuditComponent.prototype.clickTabela = function (event) {
        if (event.atributos.length > 0) {
            this.filtroAtributos = event.atributos;
        }
        this.disabledField = false;
    };
    AuditComponent.prototype.submitFilter = function (parameter) {
        var _this = this;
        var params = new http_1.HttpParams();
        var keys = Object.keys(parameter.value);
        keys.forEach(function (itm) {
            if (parameter.value[itm]) {
                params = params.append(itm, parameter.value[itm]);
            }
        });
        if (parameter.value) {
            if (this.entity != "") {
                this._http
                    .get("/" + _projectCodigo + "/api/" + this.entity, params)
                    .subscribe(function (ret) {
                    _this.colunas = [
                        {
                            caption: "#",
                            dataField: "id",
                            width: null,
                            formItem: {
                                index: 0
                            }
                        },
                        {
                            caption: "Aplicação",
                            dataField: "aplicacao",
                            width: null,
                            formItem: {
                                index: 0
                            }
                        },
                        {
                            caption: "Operação",
                            dataField: "operacao",
                            width: null,
                            formItem: {
                                index: 0
                            }
                        },
                        {
                            caption: "Data Modificação",
                            dataField: "data",
                            width: null,
                            formItem: {
                                index: 0
                            }
                        }
                    ];
                    var audit = ret.data;
                    audit.forEach(function (ret) {
                        ret["data"] = funcoes_component_1.FuncoesComponent.formatarData(ret.dataHora);
                        var lista = [];
                        var details = JSON.parse(ret.detalhes);
                        details.forEach(function (element) {
                            var keys = Object.keys(element);
                            element["lista"] = [];
                            keys.forEach(function (key) {
                                element["lista"].push({
                                    chave: key,
                                    valor: element[key]
                                });
                                // lista.push({"item": element, lista: element['lista']})
                            });
                        });
                        ret["detalhesLista"] = details;
                    });
                    _this.setGrid = ret["data"];
                });
            }
        }
    };
    AuditComponent.prototype.openDetail = function () {
        var configDialog = Object.assign(new material_1.MatDialogConfig(), {
            width: "700px",
            data: this.selectedRow
        });
        var dialogRef = this.dialog.open(dialog_audit_component_1.DialogAuditDetail, configDialog);
    };
    AuditComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.gridResultCrud.onSelectionChanged.subscribe(function (ret) {
            _this.selectedRow = ret["selectedRowKeys"];
        });
    };
    AuditComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: "sbm-audit",
                    template: require('./audit.component.html'),

                    styles: [require('./audit.component.css')],
                    host: {
                        "[class]": "columns"
                    }
                },] },
    ];
    /** @nocollapse */
    AuditComponent.ctorParameters = function () { return [
        { type: sbm_http_client_service_1.SbmHttpClientService, },
        { type: material_1.MatDialog, },
    ]; };
    AuditComponent.propDecorators = {
        "gridResultCrud": [{ type: core_1.ViewChild, args: ["gridResultCrud",] },],
        "content": [{ type: core_1.ViewChild, args: ["content",] },],
        "parameters": [{ type: core_1.ViewChild, args: ["parameters",] },],
        "entity": [{ type: core_1.Input },],
        "columns": [{ type: core_1.Input },],
    };
    return AuditComponent;
}());
exports.AuditComponent = AuditComponent;
