"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var router_1 = require("@angular/router");
var req_http_service_1 = require("../../services/req-http.service");
var notification_component_1 = require("../notification/notification.component");
var sharedService_1 = require("../../models/sharedService");
var funcoes_component_1 = require("../../models/funcoes.component");
var tabs_chrome_componente_1 = require("../tabs/tabs-chrome.component/tabs-chrome.componente");
var ngx_webstorage_1 = require("ngx-webstorage");
var BookmarkComponent = /** @class */ (function () {
    function BookmarkComponent(router, _reqService, _sharedService, _ls) {
        this.router = router;
        this._reqService = _reqService;
        this._sharedService = _sharedService;
        this._ls = _ls;
        this.isBookmarked = false;
        this.app = '';
        this.versao = '';
    }
    BookmarkComponent.prototype.checkActualRouteIsBookmarked = function () {
        var _this = this;
        var actualRoute = this.validaRetornaRota();
        if (actualRoute !== false) {
            var rotasFavoritas = this._sharedService.getLocalStorage(_projectLocalStorage, 'btn-rota-favorita', true);
            if (!rotasFavoritas) {
                if (funcoes_component_1.FuncoesComponent.isNotBlank(localStorage.getItem('__SBM-SHARED__/token'))) {
                    this._reqService.xhrGet('/sabium/api/usuario/itemfavorito').subscribe(function (ret) {
                        if (ret['success']) {
                            _this._sharedService.setLocalStorage(_projectLocalStorage, 'btn-rota-favorita', ret['res'], true);
                            _this.verificaRotaFavoritaLocalStorage(actualRoute);
                        }
                    }, function (err) {
                        console.error(err);
                    });
                }
            }
            else {
                this.verificaRotaFavoritaLocalStorage(actualRoute);
            }
        }
        else {
            this.isBookmarked = false;
        }
    };
    BookmarkComponent.prototype.verificaRotaFavoritaLocalStorage = function (actualRoute) {
        var _this = this;
        var rotasFavoritas = this._sharedService.getLocalStorage(_projectLocalStorage, 'btn-rota-favorita', true);
        var itemFavorito = rotasFavoritas.filter(function (item) {
            return item['codigoAplicacao'] == _this.app
                && item['versaoAplicacao'] == _this.versao
                && item['rota'] == actualRoute;
        });
        this.isBookmarked = (itemFavorito.length > 0);
    };
    BookmarkComponent.prototype.onClick = function ($event) {
        $event.preventDefault();
        if (this.isBookmarked) {
            this.removeBookmark();
        }
        else {
            this.addBookmark();
        }
        // Emite aviso ao lançador, para buscar novamente os favoritos
        this._sharedService.setLocalStorageShared('resetar-favoritos', 'true', true);
    };
    BookmarkComponent.prototype.addBookmark = function () {
        var _this = this;
        var route = this.validaRetornaRota();
        if (route !== false) {
            var notification_1 = new notification_component_1.NotificationComponent();
            var rotuloFavorito = this._sharedService.getLocalStorage(_projectLocalStorage, 'btn-rota-favorita-rotulo', true);
            var obj = {
                codigoAplicacao: this.app,
                versaoAplicacao: this.versao,
                rota: route,
                rotulo: rotuloFavorito ? rotuloFavorito : null
            };
            this._reqService.xhrPost('/sabium/api/usuario/itemfavorito', obj).subscribe(function (ret) {
                _this.isBookmarked = true;
                notification_1.show('Rota favoritada com sucesso!');
                // Adiciona no local storage
                // Adiciona no local storage
                _this.updateLocalStorage(route, false);
            }, function (err) {
                notification_1.show('Erro ao favoritar rota!');
            });
        }
    };
    BookmarkComponent.prototype.removeBookmark = function () {
        var _this = this;
        var route = this.validaRetornaRota();
        if (route !== false) {
            var notification_2 = new notification_component_1.NotificationComponent();
            var objEnviar = {
                codigoAplicacao: this.app,
                versaoAplicacao: this.versao,
                rota: route
            };
            this._reqService.xhrDelete('/sabium/api/usuario/itemfavorito', objEnviar).subscribe(function (ret) {
                _this.isBookmarked = false;
                _this.updateLocalStorage(route, true);
                notification_2.show('Removido rota favorita com sucesso!');
            }, function (err) {
                notification_2.show('Erro ao remover rota favorita!');
            });
        }
    };
    BookmarkComponent.prototype.validaRetornaRota = function () {
        var notification = new notification_component_1.NotificationComponent();
        if (this.app && this.versao) {
            var abaAtiva_1;
            var abasAbertas = void 0;
            abaAtiva_1 = this._sharedService.getLocalStorageShared('tab-active' + _projectCodigo);
            abasAbertas = this._sharedService.getLocalStorageShared('sbm-saved-dynamic' + _projectCodigo);
            if (abaAtiva_1 !== null && abasAbertas !== null) {
                var route = abasAbertas.find(function (i) { return i.id === abaAtiva_1.id; });
                if (route !== undefined) {
                    return JSON.stringify({
                        title: route.title,
                        html: route.html,
                        idPath: route.isPath,
                        idComp: route.idComp
                    });
                }
            }
            return false;
        }
        else if (!this.app) {
            notification.show('Código da aplicação inválido.');
            return false;
        }
        else if (!this.versao) {
            notification.show('Versão da aplicação inválida.');
            return false;
        }
        return false;
    };
    BookmarkComponent.prototype.updateLocalStorage = function (route, remove) {
        var rotasFavoritas = this._sharedService.getLocalStorage(_projectLocalStorage, 'btn-rota-favorita', true);
        if (rotasFavoritas) {
            if (remove) {
                var app_1 = this.app;
                var versao_1 = this.versao;
                var arrayRemoved = rotasFavoritas.filter(function (el) {
                    return el['codigoAplicacao'] == app_1
                        && el['versaoAplicacao'] == versao_1
                        && el['rota'] == route;
                });
                this._sharedService.setLocalStorage(_projectLocalStorage, 'btn-rota-favorita', arrayRemoved, true);
            }
            else {
                var obj = {
                    codigoAplicacao: this.app,
                    versaoAplicacao: this.versao,
                    rota: route
                };
                rotasFavoritas.push(obj);
                this._sharedService.setLocalStorage(_projectLocalStorage, 'btn-rota-favorita', rotasFavoritas, true);
            }
        }
    };
    BookmarkComponent.prototype.ngOnInit = function () {
        var _this = this;
        /*this.router.events.subscribe(e => {
                    if (e instanceof NavigationEnd) {
                        this.checkActualRouteIsBookmarked();
                    }
                });*/
        /*this.router.events.subscribe(e => {
            if (e instanceof NavigationEnd) {
                this.checkActualRouteIsBookmarked();
            }
        });*/
        tabs_chrome_componente_1.TabsChromeComponent.tabSaved.subscribe(function () {
            _this.checkActualRouteIsBookmarked();
        });
        tabs_chrome_componente_1.TabsChromeComponent.tabChange.subscribe(function () {
            _this.checkActualRouteIsBookmarked();
        });
    };
    BookmarkComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'sbm-bookmark',
                    template: require('./bookmark.component.html'),
                },] },
    ];
    /** @nocollapse */
    BookmarkComponent.ctorParameters = function () { return [
        { type: router_1.Router, },
        { type: req_http_service_1.ReqHttpService, },
        { type: sharedService_1.SharedService, },
        { type: ngx_webstorage_1.LocalStorageService, },
    ]; };
    BookmarkComponent.propDecorators = {
        "app": [{ type: core_1.Input },],
        "versao": [{ type: core_1.Input },],
    };
    return BookmarkComponent;
}());
exports.BookmarkComponent = BookmarkComponent;
