"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var notification_component_1 = require("../notification/notification.component");
var sbm_http_client_service_1 = require("../../services/sbm-http-client.service");
var select_component_1 = require("../select/select.component");
var abstract_ngmodel_1 = require("../../models/abstract.ngmodel");
var alert_component_1 = require("../alert/alert.component");
var datebox_component_1 = require("../datebox/datebox.component");
var sharedService_1 = require("../../models/sharedService");
var autocomplete_component_1 = require("../autocomplete/autocomplete.component");
var EntityComponent = /** @class */ (function () {
    function EntityComponent(service, _sharedService) {
        this.service = service;
        this._sharedService = _sharedService;
        this.entity = "";
        this.dynamic = "";
        this.isMasterDetail = false;
        this.onSubmit = new core_1.EventEmitter();
        this.update = {
            id: null,
            version: null,
            edit: false
        };
    }
    EntityComponent.prototype.reset = function () {
        this.form.reset();
    };
    EntityComponent.prototype.setValue = function (data) {
        var controls = Object.keys(data);
        if (controls.length) {
            for (var control in controls) {
                if (this.form.controls[controls[control]] !== undefined) {
                    this.form.controls[controls[control]].setValue(data[controls[control]]);
                    this.form.controls[controls[control]].markAsDirty();
                    console.log('Entity control: ', this.form.controls[controls[control]]);
                }
            }
        }
        else {
            for (var i in this.form.controls) {
                this.form.controls[i].setValue('');
            }
        }
    };
    EntityComponent.prototype.edit = function (id) {
        var _this = this;
        this.update.edit = true;
        this.update.id = id;
        var urlRest = '/' + _projectCodigo + '/api/' + ((this.dynamic) ? 'entidade/' : '') + this.entity + '/' + id;
        // var urlRest = '/recursoshumanos/api/aprovacaoferias/35'; // true
        // var urlRest = '/recursoshumanos/api/aprovacaoferias/23'; // false
        this.service.get(urlRest).subscribe(function (ret) {
            setTimeout(function () {
                _this.setValue(ret);
            }, 500);
            _this.update.version = ret.version;
        }, function (err) {
            var alert = new alert_component_1.AlertComponent();
            alert.show("Erro ao buscar o registro!", 'OK', "Não foi possível buscar este registro", 'error');
        });
    };
    EntityComponent.prototype.sendRequest = function () {
        var _this = this;
        var notification = new notification_component_1.NotificationComponent();
        var alert = new alert_component_1.AlertComponent();
        if (this.update.edit) {
            this.form.value['id'] = this.update.id;
            this.form.value['version'] = this.update.version;
        }
        // remove os itens somente leitura
        delete this.form.value['undefined'];
        if (this.entity != '') {
            var urlRest = '/' + _projectCodigo + '/api/' + ((this.dynamic) ? 'entidade/' : '') + this.entity;
            this.service.post(urlRest, new Array(this.form.value)).subscribe(function (ret) {
                notification.show("Sucesso ao salvar o registro!");
                _this.reset();
            }, function (err) {
                if (err.status == 400) {
                    var errorJson = JSON.parse(err.error);
                    var textError_1 = "";
                    if (errorJson) {
                        if (errorJson.violations) {
                            if (errorJson.violations.length > 0) {
                                errorJson.violations.forEach(function (itm) {
                                    textError_1 += itm.message + '\n';
                                });
                            }
                        }
                    }
                    alert.show("Erro ao salvar o registro!", 'OK', textError_1, 'error');
                }
            });
        }
        this.onSubmit.emit(this.form);
    };
    EntityComponent.prototype.sendForm = function () {
        var _this = this;
        var controls = Object.keys(this.form.controls);
        controls.forEach(function (key) {
            _this.form.controls[key].markAsTouched({ onlySelf: true });
            var inputs = _this.inputs.filter(function (ret) { return ret.name == key; });
            if (inputs.length > 0) {
                if (inputs[0] instanceof select_component_1.SelectComponent) {
                    inputs[0].component2.control.markAsTouched({ onlySelf: true });
                }
                else if (inputs[0] instanceof datebox_component_1.DateboxComponent) {
                    if (inputs[0].component2) {
                        inputs[0].component2.control.markAsTouched({ onlySelf: true });
                    }
                    if (inputs[0].component3) {
                        inputs[0].component3.control.markAsTouched({ onlySelf: true });
                    }
                }
                else if (inputs[0] instanceof autocomplete_component_1.AutocompleteComponent) {
                    if (inputs[0].component2) {
                        inputs[0].component2.control.markAsTouched({ onlySelf: true });
                    }
                }
            }
        });
        if (this.form.valid) {
            this.sendRequest();
        }
    };
    EntityComponent.prototype.addFormGroup = function (list) {
        var _this = this;
        if (list) {
            list.forEach(function (item) {
                if (item.isNotMasterDetail) {
                    _this.form.addControl(item.component);
                }
            });
        }
    };
    EntityComponent.prototype.ngOnChanges = function (changes) {
        // console.log('on change', changes)
    };
    EntityComponent.prototype.ngAfterViewInit = function () {
        if (!this.isMasterDetail) {
            this.addFormGroup(this.inputs);
        }
        var entityID = this._sharedService.getLocalStorage('__SBM-SABIUM-BPM__/', 'entity-id', true);
        if (entityID) {
            this.edit(entityID['id']);
        }
    };
    EntityComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'sbm-entity',
                    template: require('./entity.component.html'),

                    styles: [require('./entity.component.css')],
               },] },
    ];
    /** @nocollapse */
    EntityComponent.ctorParameters = function () { return [
        { type: sbm_http_client_service_1.SbmHttpClientService, },
        { type: sharedService_1.SharedService, },
    ]; };
    EntityComponent.propDecorators = {
        "inputs": [{ type: core_1.ContentChildren, args: [abstract_ngmodel_1.AbstractNgModel, { descendants: true },] },],
        "form": [{ type: core_1.ViewChild, args: [forms_1.NgForm,] },],
        "entity": [{ type: core_1.Input },],
        "dynamic": [{ type: core_1.Input },],
        "templateButtons": [{ type: core_1.Input },],
        "isMasterDetail": [{ type: core_1.Input, args: ['ismasterdetail',] },],
        "onSubmit": [{ type: core_1.Output },],
    };
    return EntityComponent;
}());
exports.EntityComponent = EntityComponent;
