"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var sharedService_1 = require("../../models/sharedService");
var scheduling_component_1 = require("./scheduling.component");
var parameters_component_1 = require("../parameters/parameters.component");
var req_http_service_1 = require("../../services/req-http.service");
var ScheduleProcessComponent = /** @class */ (function () {
    function ScheduleProcessComponent(_http, _sharedService) {
        this._http = _http;
        this._sharedService = _sharedService;
        this.processos = [];
        this.selectParameter = false;
        this.buttonDisable = false;
        this.showExecuteResult = false;
        this.showScheduleResult = false;
        this.comboDisabled = false;
        this.assync = false;
        this.buscandoProcessos = false;
        this.processSelected = '';
        this.codigoApp = '';
        this.versaoApp = '';
        this.processVisible = true;
    }
    ScheduleProcessComponent.prototype.clearForm = function () {
        this.sbmParameters = [];
        this.selectParameter = false;
        this._processSelected = false;
        this.buttonDisable = false;
        this.process = {};
        this.showExecuteResult = false;
    };
    ScheduleProcessComponent.prototype.returnParameters = function (data) {
        data.parameters.parametros.map(function (ret) {
            ret.chave = ret.nome;
            delete ret.nome;
        });
        data.codigo = this._processSelected.codigo;
        this.process = data;
        this.buttonDisable = !data.parametrosPreenchidosObrigatorio;
    };
    ScheduleProcessComponent.prototype.verificaParametroObrigatorio = function () {
        var botaoDesabilitar = false;
        this.sbmParameters.map(function (item) {
            if (item.obrigatorio)
                botaoDesabilitar = true;
        });
        this.buttonDisable = botaoDesabilitar;
    };
    ScheduleProcessComponent.prototype.selectProcess = function (data) {
        var newParameters = [];
        data.entrada.map(function (item) {
            var newobj = {};
            newobj.campo = null;
            newobj.nome = item.nome;
            newobj.rotulo = item.rotulo;
            newobj.obrigatorio = item.obrigatorio;
            newobj.tipo = item.tipoParametro;
            newobj.valor_padrao = "";
            newParameters.push(newobj);
        });
        this.sbmParameters = newParameters;
        this.selectParameter = true;
        this.verificaParametroObrigatorio();
    };
    ScheduleProcessComponent.prototype.sendProcess = function (process) {
        process.processo = this._processSelected.id;
        ScheduleProcessComponent.onFormSubmit.emit(process);
        this.clearForm();
    };
    ScheduleProcessComponent.prototype.ngOnInit = function () {
        if (this.processos.length == 0 && !this.buscandoProcessos && this.processVisible) {
            this.buscaProcessos();
        }
    };
    ScheduleProcessComponent.prototype.buscaProcessos = function () {
        var _this = this;
        this._http.xhrGet('/sabium/api/aplicacaoprocesso').subscribe(function (ret) {
            if (ret['success']) {
                _this.processos = ret['res']['data'];
            }
        });
    };
    ScheduleProcessComponent.prototype.setProcessoChange = function (processoSelecionar) {
        var _this = this;
        this.buscandoProcessos = true;
        this._http.xhrGet('/sabium/api/aplicacaoprocesso').subscribe(function (ret) {
            _this.buscandoProcessos = false;
            if (ret['success']) {
                _this.processos = ret['res']['data'];
                if (_this.processos && _this.processos.length > 0) {
                    var obj = _this.processos.filter(function (item) { return item.codigo == processoSelecionar; });
                    if (obj && obj.length > 0) {
                        _this._processSelected = obj[0];
                        _this.comboDisabled = true;
                        _this.selectProcess(_this._processSelected);
                        if (_this.codAgendamentoToEdit) {
                            _this.getAgendamento();
                        }
                    }
                }
            }
        });
    };
    ScheduleProcessComponent.prototype.ngOnChanges = function (changes) {
        if (changes && changes.processSelected && changes.processSelected.currentValue) {
            this.setProcessoChange(changes.processSelected.currentValue);
        }
    };
    ScheduleProcessComponent.prototype.openSchedule = function (fromEditar) {
        if (this._processSelected && this._processSelected.id) {
            this.showExecuteResult = false;
            this.showScheduleResult = true;
            var parametros_1 = [];
            this.process.parameters.parametros.forEach(function (item) {
                var objparam = {
                    chave: item.chave,
                    valor: item.valor
                };
                parametros_1.push(objparam);
            });
            var processoEnviar = {
                ordemExecucao: 0,
                processo: this._processSelected.id,
                parametros: parametros_1,
                codigoAplicacao: (this.objAgendamentoEdit ? this.objAgendamentoEdit.aplicacao.codigo : this.codigoApp),
                versaoAplicacao: (this.objAgendamentoEdit ? this.objAgendamentoEdit.aplicacao.versao.versao : this.versaoApp),
                fromEditar: fromEditar,
                objAgendamentoEdit: this.objAgendamentoEdit
            };
            this._sharedService.setLocalStorage(_projectLocalStorage, 'process-local', processoEnviar, true);
            if (this.scheduling)
                this.scheduling.buscaAgendamentoEdit();
        }
    };
    ScheduleProcessComponent.prototype.executeProcess = function () {
        if (this._processSelected && this._processSelected.id) {
            this.showExecuteResult = true;
            this.assync = true;
            this._http.xhrPost('/sabium/api/aplicacaoprocesso/' + this._processSelected.id, this.process.parameters.parametros).subscribe(function (ret) {
                console.info(ret);
            });
        }
    };
    ScheduleProcessComponent.prototype.ngOnDestroy = function () {
        this._sharedService.clearLocalStorage(_projectLocalStorage + 'process-local');
    };
    ScheduleProcessComponent.prototype.getAgendamentoProcess = function (agendamento, codProcesso) {
        this.codAgendamentoToEdit = agendamento;
        this.setProcessoChange(codProcesso);
    };
    ScheduleProcessComponent.prototype.getAgendamento = function () {
        var _this = this;
        this._http.xhrGet("/sabium/api/agendamento/" + this.codAgendamentoToEdit).subscribe(function (ret) {
            //console.log('get agendamento processo', ret);
            //console.log(this.process);
            //console.log('get agendamento processo', ret);
            //console.log(this.process);
            _this.objAgendamentoEdit = ret.res;
            var buscaTipo;
            var buscaValor;
            _this.process.parameters.parametros.map(function (item) {
                buscaTipo = _this.sbmParameters.filter(function (item2) {
                    if (item2.nome == item.chave) {
                        return item2;
                    }
                });
                buscaValor = ret.res.processos[0].parametros.filter(function (itemRet) {
                    if (item.chave == itemRet.chave) {
                        return itemRet;
                    }
                });
                if (buscaValor && buscaValor.length && buscaTipo && buscaTipo.length) {
                    item.valor = buscaValor[0].valor;
                    _this.parametersComp.modelParameter[item.chave] = item.valor;
                }
            });
            _this.parametersComp.blurParametro();
            _this.openSchedule(true);
        }, function (err) {
            //console.log(err);
        });
    };
    ScheduleProcessComponent.onFormSubmit = new core_1.EventEmitter();
    ScheduleProcessComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'sbm-schedule-process',
                    template: require('./schedule-process.component.html'),
                },] },
    ];
    /** @nocollapse */
    ScheduleProcessComponent.ctorParameters = function () { return [
        { type: req_http_service_1.ReqHttpService, },
        { type: sharedService_1.SharedService, },
    ]; };
    ScheduleProcessComponent.propDecorators = {
        "processSelected": [{ type: core_1.Input },],
        "codigoApp": [{ type: core_1.Input },],
        "versaoApp": [{ type: core_1.Input },],
        "processVisible": [{ type: core_1.Input },],
        "scheduling": [{ type: core_1.ViewChild, args: ['scheduling',] },],
        "parametersComp": [{ type: core_1.ViewChild, args: ['parametersComp',] },],
    };
    return ScheduleProcessComponent;
}());
exports.ScheduleProcessComponent = ScheduleProcessComponent;
