"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var sharedService_1 = require("../../models/sharedService");
var tabs_error_component_1 = require("./tabs-error.component");
var alert_component_1 = require("../../components/alert/alert.component");
var TabsErrorService = /** @class */ (function () {
    function TabsErrorService(_sharedService, _componentFactoryResolver) {
        var _this = this;
        this._sharedService = _sharedService;
        this._componentFactoryResolver = _componentFactoryResolver;
        this.alert = new alert_component_1.AlertComponent();
        this.errors = [];
        this.create = function (parameters) {
            var tab = _this.getCurrentTab();
            if (typeof parameters.errors !== 'undefined' && parameters.errors.length > 0) {
                if (typeof parameters.label === 'undefined' || parameters.errors.length > 1) {
                    parameters.label = 'Atenção!';
                }
                if (typeof parameters.visible === 'undefined') {
                    parameters.visible = true;
                }
                if (tab) {
                    var factory = _this._componentFactoryResolver.resolveComponentFactory(tabs_error_component_1.TabsErrorComponent);
                    var viewContainerRef = tab.tabErrorContainer;
                    var injector = core_1.ReflectiveInjector.fromResolvedProviders([], viewContainerRef.parentInjector);
                    var component = factory.create(injector);
                    for (var key in parameters) {
                        component.instance[key] = parameters[key];
                    }
                    component.changeDetectorRef.detectChanges();
                    _this.setError(true, tab);
                    viewContainerRef.clear();
                    viewContainerRef.insert(component.hostView);
                    component.instance.toggleVisibilidade.subscribe(function (response) { _this.destroy(); });
                }
                else {
                    var errors = parameters.errors.map(function (error) { return error.message; }).join('<br />');
                    _this.alert.show(parameters.label || 'Atenção', 'Ok', errors, 'error');
                }
            }
        };
        this.destroy = function () {
            var tab = _this.getCurrentTab();
            if (tab) {
                _this.setError(false, tab);
                tab.tabErrorContainer.clear();
            }
        };
        this.reset = function (errors) {
            _this.destroy();
            _this.create({ errors: errors });
        };
        sbmErrorService.push(this);
    }
    TabsErrorService.prototype.getCurrentTab = function () {
        var tabActiveId = this._sharedService.getLocalStorageShared('tab-active' + _projectCodigo);
        var tab = false;
        for (var key in SbmTabsComponent) {
            if (SbmTabsComponent[key] != null && tabActiveId != null && SbmTabsComponent[key].id == tabActiveId.id) {
                tab = SbmTabsComponent[key];
                break;
            }
        }
        return tab;
    };
    TabsErrorService.prototype.setError = function (error, tab) {
        var selector = $('.chrome-tab[data-tab="' + tab.id + '"]');
        if (error) {
            selector.addClass('error');
        }
        else {
            selector.removeClass('error');
        }
    };
    TabsErrorService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    TabsErrorService.ctorParameters = function () { return [
        { type: sharedService_1.SharedService, },
        { type: core_1.ComponentFactoryResolver, },
    ]; };
    return TabsErrorService;
}());
exports.TabsErrorService = TabsErrorService;
