"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var AbstractTabs = /** @class */ (function () {
    function AbstractTabs() {
        this.tabTemplate = "\n        <div class=\"chrome-tab\">\n          <div class=\"chrome-tab-background\">\n            <svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\"><defs><symbol id=\"topleft\" viewBox=\"0 0 214 29\" ><path d=\"M14.3 0.1L214 0.1 214 29 0 29C0 29 12.2 2.6 13.2 1.1 14.3-0.4 14.3 0.1 14.3 0.1Z\"/></symbol><symbol id=\"topright\" viewBox=\"0 0 214 29\"><use xlink:href=\"#topleft\"/></symbol><clipPath id=\"crop\"><rect class=\"mask\" width=\"100%\" height=\"100%\" x=\"0\"/></clipPath></defs><svg width=\"50%\" height=\"100%\" transfrom=\"scale(-1, 1)\"><use xlink:href=\"#topleft\" width=\"214\" height=\"29\" class=\"chrome-tab-background\"/><use xlink:href=\"#topleft\" width=\"214\" height=\"29\" class=\"chrome-tab-shadow\"/></svg><g transform=\"scale(-1, 1)\"><svg width=\"50%\" height=\"100%\" x=\"-100%\" y=\"0\"><use xlink:href=\"#topright\" width=\"214\" height=\"29\" class=\"chrome-tab-background\"/><use xlink:href=\"#topright\" width=\"214\" height=\"29\" class=\"chrome-tab-shadow\"/></svg></g></svg>\n          </div>\n          <div class=\"chrome-tab-favicon\" style=\"font-family: Material Icons; width: 2em; margin-top: 2px; vertical-align: -webkit-baseline-middle;\">\n            <i class=\"material-icons\" style=\"font-size: 20px;\"></i>\n          </div>\n          <div class=\"chrome-tab-title\"></div>\n          <div class=\"chrome-tab-close\"></div>\n        </div>\n    ";
        this.id = '';
        this.defaultTapProperties = {
            title: '',
            favicon: '',
            url: ''
        };
        this.draggabillyInstances = [];
        this.instanceId = 0;
        this.tabGeneric = [];
        this.onTabAdd = new core_1.EventEmitter();
        this.onActiveTabChange = new core_1.EventEmitter();
        this.onTabRemove = new core_1.EventEmitter();
    }
    AbstractTabs.prototype.init = function (el, options) {
        this.elTab = el;
        this.options = options;
        el.setAttribute('data-chrome-tabs-instance-id', this.instanceId);
        this.setupStyleEl();
        this.setupEvents();
        this.layoutTabs();
        this.fixZIndexes();
        this.setupDraggabilly();
        this.instanceId++;
        this.setCurrentTab(el);
    };
    AbstractTabs.prototype.setupStyleEl = function () {
        this.animationStyleEl = document.createElement('style');
        this.elTab.appendChild(this.animationStyleEl);
    };
    AbstractTabs.prototype.setupEvents = function () {
        var _this = this;
        window.addEventListener('resize', function (event) { return _this.layoutTabs(); });
        this.elTab.addEventListener('mousedown', function (e) {
            if (e.target.classList.contains('chrome-tab')) {
                e.target.childNodes.forEach(function (c) {
                    if ($(c).hasClass('chrome-tab-close') && e.which == 2) {
                        _this.removeTab(e.target);
                    }
                });
            }
        });
        this.elTab.addEventListener('click', function (_a) {
            var target = _a.target;
            if (target.classList.contains('chrome-tab')) {
                _this.setCurrentTab(target);
            }
            else if (target.classList.contains('chrome-tab-close')) {
                _this.removeTab(target.parentNode);
            }
            else if (target.classList.contains('chrome-tab-title') || target.classList.contains('chrome-tab-favicon')) {
                _this.setCurrentTab(target.parentNode);
            }
        });
    };
    Object.defineProperty(AbstractTabs.prototype, "tabEls", {
        get: function () {
            return Array.prototype.slice.call(this.elTab.querySelectorAll('.chrome-tab'));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AbstractTabs.prototype, "tabContentEl", {
        get: function () {
            return this.elTab.querySelector('.chrome-tabs-content');
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AbstractTabs.prototype, "tabWidth", {
        get: function () {
            var tabsContentWidth = this.tabContentEl.clientWidth - this.options.tabOverlapDistance;
            var width = (tabsContentWidth / this.tabEls.length) + this.options.tabOverlapDistance;
            return Math.max(this.options.minWidth, Math.min(this.options.maxWidth, width));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AbstractTabs.prototype, "tabEffectiveWidth", {
        get: function () {
            return this.tabWidth - this.options.tabOverlapDistance;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AbstractTabs.prototype, "tabPositions", {
        get: function () {
            var tabEffectiveWidth = this.tabEffectiveWidth;
            var left = 0;
            var positions = [];
            this.tabEls.forEach(function (tabEl, i) {
                positions.push(left);
                left += tabEffectiveWidth;
            });
            return positions;
        },
        enumerable: true,
        configurable: true
    });
    AbstractTabs.prototype.layoutTabs = function () {
        var _this = this;
        var tabWidth = this.tabWidth;
        this.cleanUpPreviouslyDraggedTabs();
        this.tabEls.forEach(function (tabEl) { return tabEl.style.width = tabWidth + 'px'; });
        requestAnimationFrame(function () {
            var styleHTML = '';
            _this.tabPositions.forEach(function (left, i) {
                styleHTML += "\n                    .chrome-tabs[data-chrome-tabs-instance-id=\"" + (_this.instanceId - 1) + "\"] .chrome-tabs-content .chrome-tab:nth-child(" + (i + 1) + ") {\n                      transform: translate3d(" + left + "px, 0, 0);\n                    }\n              ";
                // $(this.elTab).find('.chrome-tab').eq(i).css('transform', `translate3d(${ left }px, 0, 0)`);
            });
            _this.animationStyleEl.innerHTML = styleHTML;
            _this.styleHtmlTab = styleHTML;
        });
    };
    AbstractTabs.prototype.fixZIndexes = function () {
        var bottomBarEl = this.elTab.querySelector('.chrome-tabs-bottom-bar');
        var tabEls = this.tabEls;
        tabEls.forEach(function (tabEl, i) {
            var zIndex = tabEls.length - i;
            if (tabEl.classList.contains('chrome-tab-current')) {
                bottomBarEl.style.zIndex = tabEls.length + 1;
                zIndex = tabEls.length + 2;
            }
            tabEl.style.zIndex = zIndex;
        });
    };
    AbstractTabs.prototype.createNewTabEl = function () {
        var div = document.createElement('div');
        div.innerHTML = this.tabTemplate;
        return div.firstElementChild;
    };
    AbstractTabs.prototype.addTabComp = function (tabProperties) {
        var tabEl = this.createNewTabEl();
        tabEl.classList.add('chrome-tab-just-added');
        setTimeout(function () { return tabEl.classList.remove('chrome-tab-just-added'); }, 500);
        tabProperties = Object.assign({}, this.defaultTapProperties, tabProperties);
        this.tabContentEl.appendChild(tabEl);
        this.updateTab(tabEl, tabProperties);
        // this.emit('tabAdd', { tabEl })
        this.onTabAdd.emit(tabEl);
        this.setCurrentTab(tabEl);
        this.layoutTabs();
        this.fixZIndexes();
        this.setupDraggabilly();
        return tabEl;
    };
    AbstractTabs.prototype.setCurrentTab = function (tabEl) {
        var currentTab = this.elTab.querySelector('.chrome-tab-current');
        if (currentTab) {
            currentTab.classList.remove('chrome-tab-current');
        }
        tabEl.classList.add('chrome-tab-current');
        this.fixZIndexes();
        this.onActiveTabChange.emit(tabEl);
        AbstractTabs.tabChange.emit('activeTabChange', { tabEl: tabEl });
    };
    AbstractTabs.prototype.removeTab = function (tabEl) {
        if (tabEl.classList.contains('chrome-tab-current')) {
            if (tabEl.previousElementSibling) {
                this.setCurrentTab(tabEl.previousElementSibling);
            }
            else if (tabEl.nextElementSibling) {
                this.setCurrentTab(tabEl.nextElementSibling);
            }
        }
        var idAbaClicada = tabEl.getAttribute('data-tab');
        tabEl.parentNode.removeChild(tabEl);
        this.onTabRemove.emit(tabEl);
        this.layoutTabs();
        this.fixZIndexes();
        this.setupDraggabilly();
        this.tabGeneric.forEach(function (ret, i) {
            if (ret.instance.id == idAbaClicada) {
                ret.destroy();
            }
        });
    };
    AbstractTabs.prototype.updateTab = function (tabEl, tabProperties) {
        tabEl.querySelector('.chrome-tab-title').textContent = tabProperties.title;
        $(tabEl).find('.chrome-tab-favicon i').append(tabProperties.favicon ? tabProperties.favicon : '&#xE24D;');
        tabEl.setAttribute('data-url', tabProperties.url);
    };
    AbstractTabs.prototype.cleanUpPreviouslyDraggedTabs = function () {
        this.tabEls.forEach(function (tabEl) { return tabEl.classList.remove('chrome-tab-just-dragged'); });
    };
    AbstractTabs.prototype.setupDraggabilly = function () {
        var _this = this;
        var tabEls = this.tabEls;
        var tabEffectiveWidth = this.tabEffectiveWidth;
        var tabPositions = this.tabPositions;
        this.draggabillyInstances.forEach(function (draggabillyInstance) { return draggabillyInstance.destroy(); });
        tabEls.forEach(function (tabEl, originalIndex) {
            var originalTabPositionX = tabPositions[originalIndex];
            var draggabillyInstance = new Draggabilly(tabEl, {
                axis: 'x',
                containment: _this.tabContentEl
            });
            _this.draggabillyInstances.push(draggabillyInstance);
            draggabillyInstance.on('dragStart', function () {
                _this.cleanUpPreviouslyDraggedTabs();
                tabEl.classList.add('chrome-tab-currently-dragged');
                _this.elTab.classList.add('chrome-tabs-sorting');
                _this.fixZIndexes();
            });
            draggabillyInstance.on('dragEnd', function () {
                var finalTranslateX = parseFloat(tabEl.style.left);
                tabEl.style.transform = "translate3d(0, 0, 0)";
                // Animate dragged tab back into its place
                requestAnimationFrame(function () {
                    tabEl.style.left = '0';
                    tabEl.style.transform = "translate3d(" + finalTranslateX + "px, 0, 0)";
                    requestAnimationFrame(function () {
                        tabEl.classList.remove('chrome-tab-currently-dragged');
                        _this.elTab.classList.remove('chrome-tabs-sorting');
                        _this.setCurrentTab(tabEl);
                        tabEl.classList.add('chrome-tab-just-dragged');
                        requestAnimationFrame(function () {
                            tabEl.style.transform = '';
                            _this.setupDraggabilly();
                        });
                    });
                });
            });
            draggabillyInstance.on('dragMove', function (event, pointer, moveVector) {
                // Current index be computed within the event since it can change during the dragMove
                var tabEls = _this.tabEls;
                var currentIndex = tabEls.indexOf(tabEl);
                var currentTabPositionX = originalTabPositionX + moveVector.x;
                var destinationIndex = Math.max(0, Math.min(tabEls.length, Math.floor((currentTabPositionX + (tabEffectiveWidth / 2)) / tabEffectiveWidth)));
                if (currentIndex !== destinationIndex) {
                    _this.animateTabMove(tabEl, currentIndex, destinationIndex);
                }
            });
        });
    };
    AbstractTabs.prototype.animateTabMove = function (tabEl, originIndex, destinationIndex) {
        if (destinationIndex < originIndex) {
            tabEl.parentNode.insertBefore(tabEl, this.tabEls[destinationIndex]);
        }
        else {
            tabEl.parentNode.insertBefore(tabEl, this.tabEls[destinationIndex + 1]);
        }
    };
    AbstractTabs.tabChange = new core_1.EventEmitter();
    AbstractTabs.propDecorators = {
        "id": [{ type: core_1.Input },],
        "tabChange": [{ type: core_1.Output, args: ['tabChange',] },],
    };
    return AbstractTabs;
}());
exports.AbstractTabs = AbstractTabs;
