"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var tab_component_1 = require("./tab.component");
var TabsComponent = /** @class */ (function () {
    function TabsComponent(elRef, _renderer, _componentFactoryResolver) {
        this.elRef = elRef;
        this._renderer = _renderer;
        this._componentFactoryResolver = _componentFactoryResolver;
        this.css = 'sbm-tabs';
        this.layout = 'line';
        this.padding = '5px';
        this.closeButton = false;
        this.onTabClick = new core_1.EventEmitter();
        this.onAfterViewInit = new core_1.EventEmitter();
        this.onSelectedTab = new core_1.EventEmitter();
        this.onRemoveTab = new core_1.EventEmitter();
        this.tabsDinamic = [];
        this._columns = 'col l12 s12 m12 sbm-tabs';
        sbmTabsComponent.push(this);
    }
    Object.defineProperty(TabsComponent.prototype, "columns", {
        get: function () {
            return this._columns;
        },
        set: function (value) {
            this._columns = "col l" + value + " s12 m12";
            this._columns += ' ' + this.css;
        },
        enumerable: true,
        configurable: true
    });
    TabsComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        // this.tabs.forEach((tab, index) => {
        //     if (tab.hidden) {
        //         this.tabs.splice(index, 1);
        //     }
        // });
        jQuery(function () {
            var activeTabs = _this.tabs.filter(function (tab) { return tab.active; });
            if (activeTabs.length === 0) {
                _this.selectTab(_this.tabs.first);
            }
            else {
                _this.selectTab(activeTabs[0]);
            }
            _this.onAfterViewInit.emit();
        });
    };
    TabsComponent.prototype.removeDinamic = function (event, tab) {
        var _this = this;
        event.preventDefault();
        event.stopPropagation();
        this.tabsDinamic.map(function (item, index) {
            if (JSON.stringify(item) == JSON.stringify(tab)) {
                _this.tabsDinamic.splice(index, 1);
            }
        });
        this.onRemoveTab.emit(tab);
    };
    TabsComponent.prototype.selectedTab = function (tab) {
        this.onSelectedTab.emit(tab);
        $('.owl-dateTime-dialog').css('display', 'none');
    };
    TabsComponent.prototype.addTab = function (label, disabled, isActive, content) {
        this.tabsDinamic.push({
            _label: label,
            disabled: disabled ? true : false,
            isActive: isActive ? true : false,
            internalColumnTemplate: content
        });
    };
    TabsComponent.prototype.selectTab = function (tab) {
        var _this = this;
        if (tab) {
            this.tabs.toArray().forEach(function (item, index) {
                if (tab.randomId == item.randomId) {
                    _this.selectedIndex = index;
                }
            });
            this.onTabClick.emit(tab);
        }
    };
    TabsComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'sbm-tabs',
                    template: "\n        <mat-tab-group class=\"demo-tab-group\" #ul [(selectedIndex)]=\"selectedIndex\" (selectedTabChange)=\"selectedTab($event)\">\n            <ng-container *ngFor=\"let tab of tabs\">\n            <div *ngIf=\"!tab.hidden\">\n                <mat-tab [label]=\"tab._label\" [isActive]=\"tab.active\" [disabled]=\"tab.disabled\">\n                    <ng-template mat-tab-label *ngIf=\"closeButton\">\n                    {{tab._label}}\n                    </ng-template>\n                    <ng-template [ngTemplateOutlet]=\"tab.internalColumnTemplate\" [ngTemplateOutletContext]=\"{ item: item }\"></ng-template>\n                </mat-tab>\n            </div>\n            </ng-container>\n            <ng-container *ngFor=\"let tab of tabsDinamic\">\n                <div *ngIf=\"!tab.hidden\">\n                    <mat-tab [label]=\"tab._label\" [isActive]=\"tab.active\" [disabled]=\"tab.disabled\">\n                        <ng-template mat-tab-label *ngIf=\"closeButton\">\n                            {{tab._label}}\n\n                            <!--sbm-button design=\"floating\" css=\"close-button\" icon=\"close\"></sbm-button-->\n                            <mat-icon class=\"close-button\" (click)=\"removeDinamic($event, tab)\">close</mat-icon>\n\n                        </ng-template>\n                        <ng-template [ngTemplateOutlet]=\"tab.internalColumnTemplate\" [ngTemplateOutletContext]=\"{ item: item }\"></ng-template>\n                    </mat-tab>\n                </div>\n            </ng-container>\n        </mat-tab-group>\n\n        <div #tabsContent class=\"sbm-tabs-children-content row\" style=\"border-top: 1px solid #ddd;\" [ngStyle]=\"{'padding': padding}\">\n            <ng-content></ng-content>\n        </div>\n    ",
                    styles: ["\n        ul.tabs::-webkit-scrollbar {\n            height: 8px;\n        }\n\n        ul.tabs::-webkit-scrollbar-thumb {\n            background: #6d6d6d;\n        }\n\n        .demo-tab-group {\n            border: 1px solid #e8e8e8;\n        }\n\n        .demo-tab-content {\n            padding: 16px;\n        }\n    "],
                    host: {
                        '[class]': 'columns'
                    }
                },] },
    ];
    /** @nocollapse */
    TabsComponent.ctorParameters = function () { return [
        { type: core_1.ElementRef, },
        { type: core_1.Renderer2, },
        { type: core_1.ComponentFactoryResolver, },
    ]; };
    TabsComponent.propDecorators = {
        "el": [{ type: core_1.ViewChild, args: ['tabs',] },],
        "tabsContent": [{ type: core_1.ViewChild, args: ['tabsContent',] },],
        "ul": [{ type: core_1.ViewChild, args: ['ul', { read: core_1.ViewContainerRef },] },],
        "css": [{ type: core_1.Input },],
        "layout": [{ type: core_1.Input },],
        "padding": [{ type: core_1.Input },],
        "closeButton": [{ type: core_1.Input },],
        "onTabClick": [{ type: core_1.Output },],
        "onAfterViewInit": [{ type: core_1.Output },],
        "onSelectedTab": [{ type: core_1.Output },],
        "onRemoveTab": [{ type: core_1.Output },],
        "columns": [{ type: core_1.Input },],
        "tabs": [{ type: core_1.ContentChildren, args: [tab_component_1.TabComponent,] },],
    };
    return TabsComponent;
}());
exports.TabsComponent = TabsComponent;
