"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("rxjs/add/operator/map");
var funcoes_component_1 = require("./funcoes.component");
var en_US_1 = require("./i18n/en-US");
var pt_BR_1 = require("./i18n/pt-BR");
var i18n = /** @class */ (function () {
    function i18n(_translateService, _sharedService) {
        this._translateService = _translateService;
        this._sharedService = _sharedService;
        this.linguagemAtual = '';
        this.reqEN = en_US_1.enUS;
        this.reqPT = pt_BR_1.ptBR;
    }
    i18n.prototype.isNotBlank = function (value) {
        return funcoes_component_1.FuncoesComponent.isNotBlank(value);
    };
    i18n.prototype.iniciarIdioma = function () {
        var idiomaPadrao = "pt-BR";
        var colIdiomas = ["en-US", "pt-BR"];
        this._translateService.addLangs(colIdiomas);
        this._translateService.setDefaultLang(idiomaPadrao);
        if (this.isNotBlank(this._sharedService.getIdioma())) {
            idiomaPadrao = this._sharedService.getIdioma();
        }
        else {
            if (colIdiomas.indexOf(idiomaPadrao) == -1) {
                idiomaPadrao = "pt-BR";
            }
        }
        this.linguagemAtual = idiomaPadrao;
        this._translateService.setDefaultLang(this.linguagemAtual);
        if (!this.isNotBlank(this._sharedService.getIdioma())) {
            this._sharedService.setIdioma(this.linguagemAtual);
        }
        this.setTraducaoProjeto();
    };
    i18n.prototype.setTraducaoProjeto = function () {
        var me = this;
        var retorno;
        if (this.projectName == 'sabium-framework') {
            if (me.linguagemAtual == 'en-US') {
                retorno = me.reqEN;
            }
            else {
                retorno = me.reqPT;
            }
        }
        else {
            retorno = me.reqJSON;
        }
        me._sharedService.setTraducao(me.projectName, retorno);
        var traducao = me.getLanguage();
        me._translateService.setTranslation(me.linguagemAtual, traducao);
        me._translateService.use(me.linguagemAtual).subscribe(function (ret) {
            me._translateService.onLangChange.emit({ lang: me.linguagemAtual, translations: me._translateService.translations[me.linguagemAtual] });
        });
    };
    i18n.prototype.getLanguage = function () {
        var i18n = "{\"i18n\": {";
        var contRegistros = 0;
        for (var i = 0; i < localStorage.length; i++) {
            if (localStorage.key(i).indexOf("__SBM-SHARED__/i18n/") > -1) {
                var chave = localStorage.key(i).replace("__SBM-SHARED__/i18n/", "");
                var language = this._sharedService.getTraducao(chave);
                if (this.isNotBlank(language)) {
                    i18n += "\"" + chave + "\": " + JSON.stringify(language[0]) + ",";
                    contRegistros++;
                }
            }
        }
        if (contRegistros > 0) {
            i18n = i18n.substring(0, (i18n.length - 1));
        }
        i18n += "}}";
        return JSON.parse(i18n);
    };
    return i18n;
}());
exports.i18n = i18n;
